==> moodle-1.5-mysql.tgz: moodle/lang/zh_cn_utf8/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.5 ALPHA (2005051500)


$string['allowresubmit'] = '允许重交';
$string['assignmentdetails'] = '布置作业细节';
$string['assignmentmail'] = '{$a->teacher}已经在“{$a->assignment}”中为你提交的作业写了反馈意见。
你可以在你交的作业后面看到反馈意见：

$a->url';
$string['assignmentmailhtml'] = '{$a->teacher}已经在<i>“{$a->assignment}”</i>中为你提交的作业写了反馈意见。<br /><br />
你可以在<a href=\"$a->url\">你交的作业</a>后面看到反馈意见。';
$string['assignmentname'] = '作业名称';
$string['assignmenttype'] = '作业类型';
$string['availabledate'] = '开始日期';
$string['comment'] = '评论';
$string['commentinline'] = '内嵌点评';
$string['configmaxbytes'] = '缺省情况下站点中作业的最大尺寸(同时受课程和其它本地设置的限制)';
$string['description'] = '描述';
$string['duedate'] = '截止日期';
$string['duedateno'] = '无截止日期';
$string['early'] = '$a 之前';
$string['editmysubmission'] = '修改已提交的作业';
$string['emailteachermail'] = '{$a->username}更新了他为作业“{$a->assignment}”提交的内容。新内容位于:

$a->url';
$string['emailteachermailhtml'] = '{$a->username}更新了其作业<i>“{$a->assignment}”</i>。<br /><br />新的内容位于<a href=\"$a->url\">Web服务器</a>上。';
$string['emailteachers'] = '用E-mail提醒教师';
$string['emptysubmission'] = '您尚未提交任何内容';
$string['existingfiledeleted'] = '文件“{$a}”已被删除';
$string['failedupdatefeedback'] = '为用户{$a}更新反馈失败';
$string['feedback'] = '反馈';
$string['feedbackfromteacher'] = '来自{$a}的反馈';
$string['feedbackupdated'] = '为{$a}个人更新上交反馈';
$string['helpoffline'] = '<p>如果学生在Moodle之外完成作业（比如在其它网站，或者与教师直接交流），那么可以使用这种类型的作业。</p><p> 学生可以看到作业的描述，但不能上传包括文件在内的任何信息。教师依然可以对作业评分，学生也会得到关于他们的分数的通知。</p>';
$string['helponline'] = '<p>这种类型的作业让学生使用普通的编辑工具来编辑文本。教师可以对作业在线评分，甚至可以修改和嵌入点评到学生的答案里。</p>
<p>（如果你熟悉旧版本的Moodle，那么这种类型的作业完成和旧的日志模块相同的工作。）</p>';
$string['helpuploadsingle'] = '<p>这种类型的作业允许每个参与者上传任何类型的一个文件。</p> <p>可以是一个Word文档，一个图片，一个打包了的网站，或者任何你想让他们提交的。</p>';
$string['late'] = '$a 之后';
$string['maximumgrade'] = '最高得分';
$string['maximumsize'] = '大小限制';
$string['modulename'] = '作业';
$string['modulenameplural'] = '作业';
$string['newsubmissions'] = '已交的作业';
$string['noassignments'] = '尚无作业';
$string['noattempts'] = '尚无人尝试做此作业';
$string['notgradedyet'] = '没有评分';
$string['notsubmittedyet'] = '未交';
$string['overwritewarning'] = '警告: 重新上载将覆盖你已交的作业';
$string['preventlate'] = '不允许迟交';
$string['saveallfeedback'] = '保存我的所有反馈';
$string['submission'] = '提交';
$string['submissionfeedback'] = '对提交信息的反馈';
$string['submissions'] = '提交信息';
$string['submissionsaved'] = '已经保存了你的修改';
$string['submitassignment'] = '用此表单上交作业';
$string['submitted'] = '已交';
$string['typeoffline'] = '离线活动项目';
$string['typeonline'] = '在线文本';
$string['typeuploadsingle'] = '上载单个文件';
$string['uploadbadname'] = '该文件名含有怪异字符，无法上载';
$string['uploadedfiles'] = '已上载的文件';
$string['uploaderror'] = '在服务器上保存文件时有错误发生';
$string['uploadfailnoupdate'] = '文件上载成功但无法更新你的提交信息！';
$string['uploadfiletoobig'] = '抱歉，文件太大(最大不超过{$a}字节)';
$string['uploadnofilefound'] = '未发现任何文件——你能确定已选取了一个上载文件吗?';
$string['uploadnotregistered'] = '“{$a}”上载成功，但尚未登记!';
$string['uploadsuccess'] = '成功上载“{$a}”';
$string['viewfeedback'] = '查看作业成绩和反馈';
$string['viewsubmissions'] = '查看{$a}份已交的作业';
$string['yoursubmission'] = '你上交的作业';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/zh_cn_utf8/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.5 ALPHA (2005051500)


$string['allowresubmit'] = '允许重交';
$string['assignmentdetails'] = '布置作业细节';
$string['assignmentmail'] = '{$a->teacher}已经在“{$a->assignment}”中为您提交的作业写了反馈意见。
您可以在您交的作业后面看到反馈意见：

$a->url';
$string['assignmentmailhtml'] = '{$a->teacher}已经在<i>“{$a->assignment}”</i>中为您提交的作业写了反馈意见。<br /><br />
您可以在<a href=\"$a->url\">您交的作业</a>后面看到反馈意见。';
$string['assignmentname'] = '作业名称';
$string['assignmenttype'] = '作业类型';
$string['availabledate'] = '开始日期';
$string['comment'] = '评论';
$string['commentinline'] = '内嵌点评';
$string['configmaxbytes'] = '缺省情况下站点中作业的最大尺寸(同时受课程和其它本地设置的限制)';
$string['description'] = '描述';
$string['duedate'] = '截止日期';
$string['duedateno'] = '无截止日期';
$string['early'] = '$a 之前';
$string['editmysubmission'] = '修改已提交的作业';
$string['emailteachermail'] = '{$a->username}更新了他为作业“{$a->assignment}”提交的内容。新内容位于:

$a->url';
$string['emailteachermailhtml'] = '{$a->username}更新了其作业<i>“{$a->assignment}”</i>。<br /><br />新的内容位于<a href=\"$a->url\">Web服务器</a>上。';
$string['emailteachers'] = '用E-mail提醒教师';
$string['emptysubmission'] = '您尚未提交任何内容';
$string['existingfiledeleted'] = '文件“{$a}”已被删除';
$string['failedupdatefeedback'] = '为用户{$a}更新反馈失败';
$string['feedback'] = '反馈';
$string['feedbackfromteacher'] = '来自{$a}的反馈';
$string['feedbackupdated'] = '为{$a}个人更新上交反馈';
$string['helpoffline'] = '<p>如果学生在Moodle之外完成作业（比如在其它网站，或者与教师直接交流），那么可以使用这种类型的作业。</p><p> 学生可以看到作业的描述，但不能上传包括文件在内的任何信息。教师依然可以对作业评分，学生也会得到关于他们的分数的通知。</p>';
$string['helponline'] = '<p>这种类型的作业让学生使用普通的编辑工具来编辑文本。教师可以对作业在线评分，甚至可以修改和嵌入点评到学生的答案里。</p>
<p>（如果您熟悉旧版本的Moodle，那么这种类型的作业完成和旧的日志模块相同的工作。）</p>';
$string['helpuploadsingle'] = '<p>这种类型的作业允许每个参与者上传任何类型的一个文件。</p> <p>可以是一个Word文档，一个图片，一个打包了的网站，或者任何您想让他们提交的。</p>';
$string['late'] = '$a 之后';
$string['maximumgrade'] = '最高得分';
$string['maximumsize'] = '大小限制';
$string['modulename'] = '作业';
$string['modulenameplural'] = '作业';
$string['newsubmissions'] = '已交的作业';
$string['noassignments'] = '尚无作业';
$string['noattempts'] = '尚无人尝试做此作业';
$string['notgradedyet'] = '没有评分';
$string['notsubmittedyet'] = '未交';
$string['overwritewarning'] = '警告: 重新上载将覆盖您已交的作业';
$string['preventlate'] = '不允许迟交';
$string['saveallfeedback'] = '保存我的所有反馈';
$string['submission'] = '提交';
$string['submissionfeedback'] = '对提交信息的反馈';
$string['submissions'] = '提交信息';
$string['submissionsaved'] = '已经保存了您的修改';
$string['submitassignment'] = '用此表单上交作业';
$string['submitted'] = '已交';
$string['typeoffline'] = '离线活动项目';
$string['typeonline'] = '在线文本';
$string['typeuploadsingle'] = '上载单个文件';
$string['uploadbadname'] = '该文件名含有怪异字符，无法上载';
$string['uploadedfiles'] = '已上载的文件';
$string['uploaderror'] = '在服务器上保存文件时有错误发生';
$string['uploadfailnoupdate'] = '文件上载成功但无法更新您的提交信息！';
$string['uploadfiletoobig'] = '抱歉，文件太大(最大不超过{$a}字节)';
$string['uploadnofilefound'] = '未发现任何文件——您能确定已选取了一个上载文件吗?';
$string['uploadnotregistered'] = '“{$a}”上载成功，但尚未登记!';
$string['uploadsuccess'] = '成功上载“{$a}”';
$string['viewfeedback'] = '查看作业成绩和反馈';
$string['viewsubmissions'] = '查看{$a}份已交的作业';
$string['yoursubmission'] = '您上交的作业';

?>
